@@ -20,23 +20,26 @@
 #
 package PException;
 
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
+use	strict;
+use	vars	qw( $VERSION @ISA @EXPORT @EXPORT_OK $_XCPHDL_ );
 
-use Debug ( 0 );
+#sub DEBUG { 5 }
+#sub debug { print STDERR join( " ! ", @_ ) if $_[0] >= DEBUG }
+sub debug { }
 
 require Exporter;
 
-$VERSION= "2.3";
+$VERSION= "2.4";
 
 =pod
 
 =head1 NAME
 
-Exception - Exception manager
+PException - Exception manager
 
 =head1 SYNOPSIS
 
-  use Exception;
+  use PException;
 
 
   try {
@@ -54,21 +57,30 @@ Exception - Exception manager
 @EXPORT		= qw( throw try );
 @EXPORT_OK	= qw( );
 
-$_XCPHDL_	= [ { 
-	EXCEPTIONS	=> 1,
-	FLYS		=> 2,
-	STACKFLY	=> 3,
-	ONFLY		=> 4,
-	FRESH		=> 5,
-	CANDIE		=> 6
-  }, [], [], [], 0, 0, 0 ];
+#my $_XCPHDL_	= [ { 
+#	EXCEPTIONS	=> 1,
+#	FLYS		=> 2,
+#	STACKFLY	=> 3,
+#	ONFLY		=> 4,
+#	FRESH		=> 5,
+#	CANDIE		=> 6
+#  }, [], [], [], 0, 0, 0 ];
+
+$_XCPHDL_	= {
+	EXCEPTIONS	=> [],
+	FLYS		=> [],
+	STACKFLY	=> [],
+	ONFLY		=> 0,
+	FRESH		=> 0,
+	CANDIE		=> 0
+  };
 
 BEGIN
 {
   $SIG{__WARN__}	= \&__onflyhandler;
 
   $SIG{__DIE__}		= sub	{
-#	$Exception::_XCPHDL_->{CANDIE}	= 1;
+#	$PException::_XCPHDL_->{CANDIE}	= 1;
 
 #	if( $@ && hadWaittingExceptions() )
 #				{ debug( 2, "NN-> $@ <" ) }
@@ -101,35 +113,33 @@ sub	try(&@)
 {
 	my $e	= shift;
 
-	my	@catch	= grep { $_->isa("Exception::CATCH") } @_;
-	my	@onfly	= grep { $_->isa("Exception::ONFLY") } @_;
+	my	@catch	= grep { $_->isa("PException::CATCH") } @_;
+	my	@onfly	= grep { $_->isa("PException::ONFLY") } @_;
 
 ## add an new stack of onfly exception
 
-	push( @{$Exception::_XCPHDL_->{STACKFLY}}, [ @onfly ] );
+	push( @{$PException::_XCPHDL_->{STACKFLY}}, [ @onfly ] );
 
-	#debug( 1, "try\t\t", $e, @_ );
+#	debug( 1, "try", $e, @_ );
 
 	eval { &$e; };
 
 ## remove the stack of onfly exception
 
-	pop( @{$Exception::_XCPHDL_->{STACKFLY}} );
+	pop( @{$PException::_XCPHDL_->{STACKFLY}} );
 
-	if( $@ && hadWaittingExceptions() )
-	{
-#	  chomp( $@ );
-	  #debug( 2, "---> $@ <" );
+	if( $@ && hadWaittingExceptions() ) {
+	  chomp( $@ );
+#	  debug( 2, "---> $@ <" );
 	  throw() if checkException( @catch );
 	}
-	elsif ( $@ )
-	{
-#	  chomp( $@ );
-	  #debug( 2, "no-> $@ <" );
+	elsif ( $@ ) {
+	  chomp( $@ );
+#	  debug( 2, "no-> $@ <" );
 	  $@	= undef;
 	}
 
-	#debug( 2, "STACKFLY", scalar( @{$Exception::_XCPHDL_->{STACKFLY}} ) );
+#	debug( 2, "STACKFLY", scalar( @{$PException::_XCPHDL_->{STACKFLY}} ) );
 }
 
 =pod
@@ -142,30 +152,28 @@ throw a list of exceptions.
 
 sub	throw(@)
 {
-  #debug( 1, "throw\t", "begin" );
+#  debug( 1, "throw", "begin" );
 
-  $Exception::_XCPHDL_->{FRESH}	= 0;
-  if	( scalar(@_) > 0 )
-  {
-	push( @{$Exception::_XCPHDL_->{EXCEPTIONS}}, @_ );
-	$Exception::_XCPHDL_->{FRESH}	= 1;
+  $PException::_XCPHDL_->{FRESH}	= 0;
+  if	( @_ > 0 ) {
+	push( @{$PException::_XCPHDL_->{EXCEPTIONS}}, @_ );
+	$PException::_XCPHDL_->{FRESH}	= 1;
   }
 
-  my @tmp	= @{$Exception::_XCPHDL_->{EXCEPTIONS}};
+  my @tmp	= @{$PException::_XCPHDL_->{EXCEPTIONS}};
 
-  #debug( 2, "throw\t", @tmp );
+#  debug( 2, "throw", @tmp );
 
   map { $_ = ref($_) . "($$_)" } @tmp;
 
-  if ( !$Exception::_XCPHDL_->{ONFLY} && $Exception::_XCPHDL_->{CANDIE} )
-  {
-	#debug( 2, "throw\t", "Die" );
+  if ( !$PException::_XCPHDL_->{ONFLY} && $PException::_XCPHDL_->{CANDIE} ) {
+#	debug( 2, "throw", "Die" );
 	$_XCPHDL_->{CANDIE}	= 0;
 	die( join( "\t- ", "Die", @tmp ) );
   }
-  elsif( !$Exception::_XCPHDL_->{ONFLY} )
+  elsif( !$PException::_XCPHDL_->{ONFLY} )
   {
-	#debug( 2, "throw\t", "Warn" );
+#	debug( 2, "throw", "Warn" );
 	warn( join( "\t- ", "Warn", @tmp ) );
   }
 }
@@ -179,8 +187,7 @@ create a new instance of an Exception.
 
 =cut
 
-sub	new($@)
-{
+sub	new($@) {
   my $classe	= shift;
   my $sc	= shift;
 
@@ -218,7 +225,7 @@ block where the exception appear.
 
 =cut
 sub	addFlyingHandler($&)
-{ push( @{$Exception::_XCPHDL_->{FLYS}}, newTypedCatching( $_[0], $_[1], "FLYS" ) ) }
+{ push( @{$PException::_XCPHDL_->{FLYS}}, newTypedCatching( $_[0], $_[1], "FLYS" ) ) }
 
 
 =pod
@@ -234,7 +241,7 @@ sub	addFlyingHandler($&)
 return true if there is waitting exceptions, false elsewhere
 
 =cut
-sub	hadWaittingExceptions	{ return scalar(@{$Exception::_XCPHDL_->{EXCEPTIONS}})>0 }
+sub	hadWaittingExceptions	{ return scalar(@{$PException::_XCPHDL_->{EXCEPTIONS}})>0 }
 
 
 =pod
@@ -245,27 +252,25 @@ create an object for catching methods.
 when a catch happens, 
 
 =cut
-sub	newTypedCatching($$$)
-{
+sub	newTypedCatching($$$) {
   my ( $s, $c, $sig ) = @_;
 
   if	( !defined( $c ) )
-	{ $c = sub {}	unless	( $c = $s->can( handleException ) ) }
+	{ $c = sub {}	unless	( $c = $s->can( "handleException" ) ) }
 
-  return bless sub()
-  {
-	#debug( 1, $sig,$s, $c, @{$Exception::_XCPHDL_->{EXCEPTIONS}} );
+  return bless sub() {
+	debug( 1, $sig, $s, $c, @{$PException::_XCPHDL_->{EXCEPTIONS}} );
 
-	if ( my @tmp = grep { $_->isa($s) } @{$Exception::_XCPHDL_->{EXCEPTIONS}} )
+	if ( my @tmp = grep { $_->isa($s) } @{$PException::_XCPHDL_->{EXCEPTIONS}} )
 	{
-		@{$Exception::_XCPHDL_->{EXCEPTIONS}} =
-			grep { !($_->isa($s)) } @{$Exception::_XCPHDL_->{EXCEPTIONS}};
+		@{$PException::_XCPHDL_->{EXCEPTIONS}} =
+			grep { !($_->isa($s)) } @{$PException::_XCPHDL_->{EXCEPTIONS}};
 		&$c(@tmp);
-#		@{$Exception::_XCPHDL_->{EXCEPTIONS}} = ( @{$Exception::_XCPHDL_->{EXCEPTIONS}}, @tmp );
+#		@{$PException::_XCPHDL_->{EXCEPTIONS}} = ( @{$PException::_XCPHDL_->{EXCEPTIONS}}, @tmp );
 		return 1;
 	}
 	return 0;
-  }, "Exception::$sig";
+  }, "PException::$sig";
 }
 
 =pod
@@ -275,8 +280,7 @@ sub	newTypedCatching($$$)
 control if there is some exceptions to catch & treat in an stack
 
 =cut
-sub	checkException(@)
-{
+sub	checkException(@) {
   foreach(@_){&{$_}()}
   return hadWaittingExceptions();
 }
@@ -300,51 +304,45 @@ sub	handleException		{ }
 the handler which intercept __WARN__ or __DIE__ signal
 
 =cut
-sub	__onflyhandler
-{
-  if	( hadWaittingExceptions() )
-  {
+sub	__onflyhandler {
+  if	( hadWaittingExceptions() ) {
 	my ( @tmp );
-	#debug( 1, "FLYS HANDLER", "Begin" );
+#	debug( 1, "FLYS HANDLER", "Begin" );
 
 ## get the current stack of onfly exception
-	if	( scalar( @{$Exception::_XCPHDL_->{STACKFLY}} ) )
-	{
-	  @tmp	= @{$Exception::_XCPHDL_->{STACKFLY}->[
-			$#{$Exception::_XCPHDL_->{STACKFLY}}]};
-	}
-	else	{
+	if	( scalar( @{$PException::_XCPHDL_->{STACKFLY}} ) ) {
+	  @tmp	= @{$PException::_XCPHDL_->{STACKFLY}->[
+			$#{$PException::_XCPHDL_->{STACKFLY}}]};
+	} else {
 	  my ( $i, @tmp ) = ( 0 );
 
 	  while( @tmp = caller( $i++ ) )
 	  { print STDERR "$i\t> " . join( " + ", grep { defined $_ } @tmp, "\n" ) }
 
-	  for ( @{$Exception::_XCPHDL_->{EXCEPTIONS}} )
+	  for ( @{$PException::_XCPHDL_->{EXCEPTIONS}} )
 		{ print STDERR "\t>$_ - ", $$_ , "\n" }
-	  die( "ya1kouille! Exception thrown with no try block" )
+	  die( "ya1kouille! PException thrown with no try block" )
 	}
 
-	#debug( 2, "FLYS HANDLER", @tmp );
+#	debug( 2, "FLYS HANDLER", @tmp );
 
 ## add flying handlers if fresh exception
-	push( @tmp, @{$Exception::_XCPHDL_->{FLYS}} )
-		if ( ( $Exception::_XCPHDL_->{FRESH} ) &&
-			scalar( @{$Exception::_XCPHDL_->{FLYS}} ) );
+	push( @tmp, @{$PException::_XCPHDL_->{FLYS}} )
+		if ( ( $PException::_XCPHDL_->{FRESH} ) &&
+			scalar( @{$PException::_XCPHDL_->{FLYS}} ) );
 
-	$Exception::_XCPHDL_->{ONFLY}	= 1;
+	$PException::_XCPHDL_->{ONFLY}	= 1;
 
-	if	( checkException( @tmp ) )
-	{
-	  #debug( 2, "FLYS HANDLER", "Following" );
-	  $Exception::_XCPHDL_->{ONFLY}	= 0;
-	  $Exception::_XCPHDL_->{CANDIE}= 1;
+	if	( checkException( @tmp ) ) {
+#	  debug( 2, "FLYS HANDLER", "Following" );
+	  $PException::_XCPHDL_->{ONFLY}	= 0;
+	  $PException::_XCPHDL_->{CANDIE}= 1;
 	  throw();
 	}
-	#debug( 2, "FLYS HANDLER", "End" );
+#	debug( 2, "FLYS HANDLER", "End" );
 	undef $@;
-	$Exception::_XCPHDL_->{ONFLY}	= 0;
-  }
-  else	{ print STDERR $@ }
+	$PException::_XCPHDL_->{ONFLY}	= 0;
+  } else { print STDERR $@ }
 }
 
 __END__
@@ -372,17 +370,17 @@ __END__
 
 =item	EXCEPTIONS
 
-@{$Exception::_XCPHDL_->{EXCEPTIONS}} is the stack of thrown
+@{$PException::_XCPHDL_->{EXCEPTIONS}} is the stack of thrown
 exceptions.
 
 =item	FLYS
 
-@{$Exception::_XCPHDL_->{FLYS}} is the stack of fly exception
+@{$PException::_XCPHDL_->{FLYS}} is the stack of fly exception
 handler.
 
 =item	STACKFLY
 
-@{$Exception::_XCPHDL_->{STACKFLY}} contain a stack of the list of
+@{$PException::_XCPHDL_->{STACKFLY}} contain a stack of the list of
 onfly exception. each list is linked to a nested try.
 
 =item	ONFLY
@@ -404,7 +402,7 @@ is up when a die call must be done.
 a try block is a code block which is evaluated.
 
 when you throw a new set of exception, this set is pushed in
-@{$Exception::_XCPHDL_->{EXCEPTIONS}} , the system call die.
+@{$PException::_XCPHDL_->{EXCEPTIONS}} , the system call die.
 
 =head2	Onfly mechanism
 
@@ -434,7 +432,7 @@ are thrown when others exceptions are thrown )
 interact with the engine
 
 =item	Add a "transaction" try ( aka try blocks wich are executed totaly or
-not )
+not ) if it's possible
 
 =item	Add other tests ...
 
